@@ -11,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '4.30';
+our $VERSION = '5.00';
 
 URPM->bootstrap($VERSION);
 
@@ -733,6 +733,18 @@ Just the obsoleted package name.
 
 =item $package->pack_header()
 
+If a header is associated with the package, fill the package fields from
+the header's tags (NEVRA,
+requires/recommends/obsoletes/conflicts/provides/summary)
+then free the header
+
+It's useful when traversing the rpm DB, if one wants to keep around a
+package from the DB
+else the info would not be available outside the traverse_*() function.
+
+It's also useful when creating a URPM_Package from a package file in
+order to shrink memory footprint.
+
 =item $package->packager()
 
 =item $package->payload_format()
@@ -759,7 +771,7 @@ Full requires tags
 
 Just the required package name.
 
-=item $package->suggests()
+=item $package->recommends_nosense()
 
 =item $package->rflags()
 
